/*  Copyright (C) 2010-2024 Institute of Aerospace Systems, RWTH Aachen University - All rights reserved.
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "bwbCalculatePolar.h"

#include <moduleBasics/strategySelector.h>
#include <moduleBasics/report.h>
#include <moduleBasics/plot.h>
#include <aixml/node.h>

#include <algorithm>
#include <memory>
#include <exception>
#include <iomanip>
#include <string>
#include <vector>
#include <utility>  // make_pair

#include "bwbDefaultStrategy.h"
#include "bwbCalculatePolarConfig.h"

#ifdef _WIN32
    #include <fileapi.h>
    #include <windows.h>
#endif  // _WIN32

using std::endl;
using std::exception;
using std::fixed;
using std::ofstream;
using std::setprecision;
using std::string;
using std::stringstream;
using std::vector;

void bwbCalculatePolar::initialize() {
    config_ = std::make_shared<bwbCalculatePolarConfig>(rtIO_->moduleConfig);
    //data_ = std::make_shared<bwbCalculatePolarData>(rtIO_->acxml);
    myBWBDefaultStrategy = std::make_shared<bwbDefaultStrategy>(rtIO_, config_);
}

void bwbCalculatePolar::run() {
    myBWBDefaultStrategy->run();
}

void bwbCalculatePolar::update() {
    myBWBDefaultStrategy->writePolarXML();
    myBWBDefaultStrategy->writeXMLOutputData();
}

void bwbCalculatePolar::report() {
    myBWBDefaultStrategy->writePolarData();
}

void bwbCalculatePolar::save() {
}