def calculate_flight_kilometer_costs(dict_ac_data, dict_operating_costs, runtime_output):
    """Calculate flight kilometer costs.

    The flight kilometer costs are very flexible and suitable for an extended consideration of changed route structures.
    This parameter allows the range potential of the aircraft to be assessed.

    This function adds the 'flight_kilometer_costs' dict to the 'dict_operating_costs' that contains the following
    parameters:
        - array flight_kilometer_costs: Flight kilometer costs (range dependent) in EUR/km

    :param dict dict_ac_data: Dict containing parameters and values from aircraft exchange and module configuration file
    :param dict dict_operating_costs: Dict containing parameters from cost estimation calculation
    :param logging.Logger runtime_output: Logging object used for capturing log messages in the module
    :return dict dict_operating_costs: Dict containing parameters from cost estimation calculation
    """

    # Extract necessary values from 'dict_operating_costs'.
    direct_operating_costs_annual = dict_operating_costs['direct_operating_costs']['direct_operating_costs_annual']
    ranges_for_prd = dict_operating_costs['payload_range_diagram_data']['ranges_for_prd']/1000

    # Replace zero range to eliminate 'division by zero' warning.
    if ranges_for_prd[0] == 0:
        ranges_for_prd[0] = 1e-8
    # Calculate flight kilometer costs.
    flight_kilometer_costs = direct_operating_costs_annual / ranges_for_prd

    # Prepare output data.
    dict_operating_costs['flight_kilometer_costs'] = {}
    dict_operating_costs['flight_kilometer_costs']['flight_kilometer_costs'] = flight_kilometer_costs

    return dict_operating_costs
