
# LCA_schaefer {#lca-schaefer}
The method is based on the dissertation by Katharina Schäfer (2011) \cite Sch17. It is highly recommended to refer to this work for detailed insights. The method calculates the energy demand and emissions across the aircraft's life cycle phases: development, production, operation, and end-of-life. The following image shows the processes considered.
![](ecological_assessment/lifeCyclePhases.png "Life cycle phases according to K.Schaefer")

## General principles {#lca-schaefer-generalprinciples}
For all processes within the four phases, an inventory analysis is conducted. The function `calculateResources` collects all relevant inputs, such as materials and energy demand. Next, `calculateEmissions` determines the resulting emissions. For background processes, data provided primarily by [GaBi Software](https://ghgprotocol.org/gabi-databases) is used, offering emission data for material extraction, fuel production, energy production, and more.
If recycling is enabled, emissions in the end-of-life phase can be negative, as the emissions saved in the production phase due to recycling are accounted for here.

## Input-Data {#lca-schaefer-input}
@note The following lists show only the data that is directly read by the module. For data required by the libraries in use, please refer to the respective documentation.

The method reads following data from the acXML file:
```xml
<aircraft_exchange_file>
    <requirements_and_specifications>
        <general>
            <type>
                <value>CeRAS</value>
            </type>
            <model>
                <value>SMR-2020</value>
            </model>
        </general>
        <design_specification>
            <transport_task>
                <passenger_definition>
                    <total_number_passengers>
                        <unit>1</unit>
                        <value>162</value>
                        <lower_boundary>0</lower_boundary>
                        <upper_boundary>1000</upper_boundary>
                    </total_number_passengers>
                </passenger_definition>
            </transport_task>
        </design_specification>
        <requirements>
            <top_level_aircraft_requirements>
                <flight_envelope>
                    <maximum_operating_velocity>
                        <unit>m/s</unit>
                        <value>180</value>
                        <lower_boundary>50</lower_boundary>
                        <upper_boundary>250</upper_boundary>
                    </maximum_operating_velocity>
                </flight_envelope>
                <study_mission>
                    <range>
                        <unit>m</unit>
                        <value>1481600</value>
                        <lower_boundary>0</lower_boundary>
                        <upper_boundary>20000000</upper_boundary>
                    </range>
                    <payload_fractions>
                        <passenger_mass_fraction>
                            <unit>1</unit>
                            <value>0.75</value>
                            <lower_boundary>0</lower_boundary>
                            <upper_boundary>1</upper_boundary>
                        </passenger_mass_fraction>
                    </payload_fractions>
                </study_mission>
            </top_level_aircraft_requirements>
        </requirements>
        <assessment_scenario>
            <flights_per_year>
                <unit>1</unit>
                <value>2227</value>
                <lower_boundary>0</lower_boundary>
                <upper_boundary>4000</upper_boundary>
            </flights_per_year>
            <duration_operation>
                <unit>a</unit>
                <value>25</value>
                <lower_boundary>0</lower_boundary>
                <upper_boundary>50</upper_boundary>
            </duration_operation>
        </assessment_scenario>
        <mission_files>
            <design_mission_file>
                <value>design_mission.xml</value>
            </design_mission_file>
        </mission_files>
    </requirements_and_specifications>
    <component_design>
        <propulsion>
            <specific>
                <propulsion ID="0">
                    <engine>
                        <scale_factor>
                            <unit>1</unit>
                            <value>0.9064775155</value>
                            <lower_boundary>-inf</lower_boundary>
                            <upper_boundary>inf</upper_boundary>
                        </scale_factor>
                        <model>
                            <value>PW1127G-JM</value>
                        </model>
                        <bucket_point>
                            <thrust>
                                <unit>N</unit>
                                <value>18391.6134</value>
                                <lower_boundary>-inf</lower_boundary>
                                <upper_boundary>inf</upper_boundary>
                            </thrust>
                            <tsfc>
                                <unit>kg/Ns</unit>
                                <value>1.407077304e-05</value>
                                <lower_boundary>-inf</lower_boundary>
                                <upper_boundary>inf</upper_boundary>
                            </tsfc>
                        </bucket_point>
                        <mass_properties>
                            <mass>
                                <unit>kg</unit>
                                <value>2565.399255</value>
                                <lower_boundary>-inf</lower_boundary>
                                <upper_boundary>inf</upper_boundary>
                            </mass>
                        </mass_properties>
                    </engine>
                    <nacelle ID="0">
                        <mass_properties>
                            <mass>
                                <unit>kg</unit>
                                <value>1021.17164</value>
                                <lower_boundary>-inf</lower_boundary>
                                <upper_boundary>inf</upper_boundary>
                            </mass>
                        </mass_properties>
                    </nacelle>
                    <pylon ID="0">
                        <mass_properties>
                            <mass>
                                <unit>kg</unit>
                                <value>495.2910093</value>
                                <lower_boundary>-inf</lower_boundary>
                                <upper_boundary>inf</upper_boundary>
                            </mass>
                        </mass_properties>
                    </pylon>
                </propulsion>
            </specific>
            <mass_properties>
                <mass>
                    <unit>kg</unit>
                    <value>8163.723809</value>
                    <lower_boundary>-inf</lower_boundary>
                    <upper_boundary>inf</upper_boundary>
                </mass>
            </mass_properties>
        </propulsion>
        <systems>
            <specific>
                <maximium_power_demand>
                    <unit>W</unit>
                    <value>249540.7594</value>
                    <lower_boundary>0</lower_boundary>
                    <upper_boundary>inf</upper_boundary>
                </maximium_power_demand>
                <geometry>
                    <mass_properties>
                        <bleed_air_system>
                            <unit>kg</unit>
                            <value>170.9024353</value>
                            <lower_boundary>0</lower_boundary>
                            <upper_boundary>inf</upper_boundary>
                        </bleed_air_system>
                        <fuel_system>
                            <unit>kg</unit>
                            <value>0</value>
                            <lower_boundary>0</lower_boundary>
                            <upper_boundary>inf</upper_boundary>
                        </fuel_system>
                    </mass_properties>
                </geometry>
            </specific>
            <mass_properties>
                <mass>
                    <unit>kg</unit>
                    <value>4825.986695</value>
                    <lower_boundary>0</lower_boundary>
                    <upper_boundary>inf</upper_boundary>
                </mass>
            </mass_properties>
        </systems>
        <wing>
            <mass_properties>
                <mass>
                    <unit>kg</unit>
                    <value>5899.686597</value>
                    <lower_boundary>0</lower_boundary>
                    <upper_boundary>inf</upper_boundary>
                </mass>
            </mass_properties>
        </wing>
        <fuselage>
            <mass_properties>
                <mass>
                    <unit>kg</unit>
                    <value>14004.22881</value>
                    <lower_boundary>0</lower_boundary>
                    <upper_boundary>inf</upper_boundary>
                </mass>
            </mass_properties>
        </fuselage>
        <landing_gear>
            <mass_properties>
                <mass>
                    <unit>kg</unit>
                    <value>2558.0104</value>
                    <lower_boundary>0</lower_boundary>
                    <upper_boundary>inf</upper_boundary>
                </mass>
            </mass_properties>
        </landing_gear>
        <empennage>
            <specific>
                <geometry>
                    <aerodynamic_surface ID="0">
                        <name>
                            <value>vertical_stabiliser</value>
                        </name>
                        <mass_properties>
                            <mass>
                                <unit>kg</unit>
                                <value>566.1125139</value>
                                <lower_boundary>-inf</lower_boundary>
                                <upper_boundary>inf</upper_boundary>
                            </mass>
                        </mass_properties>
                    </aerodynamic_surface>
                    <aerodynamic_surface ID="1">
                        <name>
                            <value>horizontal_stabiliser</value>
                        </name>
                        <mass_properties>
                            <mass>
                                <unit>kg</unit>
                                <value>759.3554913</value>
                                <lower_boundary>-inf</lower_boundary>
                                <upper_boundary>inf</upper_boundary>
                            </mass>
                        </mass_properties>
                    </aerodynamic_surface>
                </geometry>
            </specific>
        </empennage>
    </component_design>
    <analysis>
        <aerodynamics>
            <reference_values>
                <S_ref>
                    <unit>m^2</unit>
                    <value>105.2800817</value>
                    <lower_boundary>-inf</lower_boundary>
                    <upper_boundary>inf</upper_boundary>
                </S_ref>
            </reference_values>
        </aerodynamics>
        <masses_cg_inertia>
            <maximum_takeoff_mass>
                <mass_properties>
                    <mass>
                        <unit>kg</unit>
                        <value>64586.71283</value>
                        <lower_boundary>0</lower_boundary>
                        <upper_boundary>300000</upper_boundary>
                    </mass>
                </mass_properties>
            </maximum_takeoff_mass>
            <operating_mass_empty>
                <mass_properties>
                    <mass>
                        <unit>kg</unit>
                        <value>36354.88581</value>
                        <lower_boundary>0</lower_boundary>
                        <upper_boundary>inf</upper_boundary>
                    </mass>
                </mass_properties>
            </operating_mass_empty>
            <manufacturer_mass_empty>
                <mass_properties>
                    <mass>
                        <unit>kg</unit>
                        <value>33257.87662</value>
                        <lower_boundary>0</lower_boundary>
                        <upper_boundary>inf</upper_boundary>
                    </mass>
                </mass_properties>
            </manufacturer_mass_empty>
        </masses_cg_inertia>
        <mission>
            <design_mission>
                <range>
                    <unit>m</unit>
                    <value>4538402.27</value>
                    <lower_boundary>0</lower_boundary>
                    <upper_boundary>5000000</upper_boundary>
                </range>
                <block_time>
                    <unit>s</unit>
                    <value>20978.31905</value>
                    <lower_boundary>0</lower_boundary>
                    <upper_boundary>45000</upper_boundary>
                </block_time>
                <flight_time>
                    <unit>s</unit>
                    <value>20138.31905</value>
                    <lower_boundary>0</lower_boundary>
                    <upper_boundary>44500</upper_boundary>
                </flight_time>
                <taxi_energy ID="0">
                    <taxi_out_energy ID="0">
                        <consumed_energy>
                            <unit>J</unit>
                            <value>0</value>
                            <lower_boundary>0</lower_boundary>
                            <upper_boundary>1e+12</upper_boundary>
                        </consumed_energy>
                    </taxi_out_energy>
                </taxi_energy>
            </design_mission>
            <study_mission>
                <flight_time>
                    <unit>s</unit>
                    <value>20138.31905</value>
                    <lower_boundary>0</lower_boundary>
                    <upper_boundary>44500</upper_boundary>
                </flight_time>
                <taxi_energy ID="0">
                    <taxi_out_energy ID="0">
                        <consumed_energy>
                            <unit>J</unit>
                            <value>0</value>
                            <lower_boundary>0</lower_boundary>
                            <upper_boundary>1e+12</upper_boundary>
                        </consumed_energy>
                    </taxi_out_energy>
                </taxi_energy>
                <in_flight_energy>
                    <trip_energy ID="0">
                        <consumed_energy>
                            <unit>J</unit>
                            <value>0</value>
                            <lower_boundary>0</lower_boundary>
                            <upper_boundary>1e+12</upper_boundary>
                        </consumed_energy>
                    </trip_energy>
                </in_flight_energy>
            </study_mission>
        </mission>
    </analysis>
</aircraft_exchange_file>
```
In the `ecological_assessment_conf.xml`, next to the control settings block, the following program settings are needed:
```xml
<program_settings description="Program specific settings for this tool">
		<strategy_selector description="Define which strategy shall be used. By now, only 'standard' is implemented which offers different methods">
			<value>STANDARD</value>
		</strategy_selector>
		<standard_strategy description="Settings for standard strategy. Different methods can be used by defining them in this block.">
			<emission_calculation description="Settings for the emission calculation">
				<life_cycle_emissions_methods description="Settings for life cylce emission calculation">
					<method description="Sets method to calculate life cycle emissions ('NO': no calculation, 'SCHAFER': calculation according to K.Schäfer(2018)">
						<value>SCHAEFER</value>
					</method>
					<schaefer description="Settings for the emission calculations according to K.Schäfer(2018)">
						<engine_mode_switch description="Includes engine life cycle in calculation (Dev+Production+Maintenance+EoL). Switch: true (engine included) / false (engine not included)">
							<value>true</value>
						</engine_mode_switch>
						<engine_engineering_ratio description="Engineering effort for engines relative to whole aircraft (derived from Micado CSR-02 costs)">
							<value>0.2113</value>
							<unit>1</unit>
							<lower_boundary>0</lower_boundary>
							<upper_boundary>1</upper_boundary>
						</engine_engineering_ratio>
						<development_phase description="Settings for the calculation of the development phase">
							<test_phase description="Settings for calculation of test emissions">
								<development_emission_setting description="Selects scope of development emission calculation. Selector: mode_0 (no development emissions) / mode_1 (development emissions without production/endOfLife emissions of test components) / mode_2 (development emissions with production/endOfLife emissions of test components)">
									<value>mode_2</value>
								</development_emission_setting>
								<aircraft_specs description="Aircraft specifications needed for development calculations">
									<ETOPS_switch description="Aircraft and engine(s) will be tested for ETOPS (Extended-range Twin-engine Operations Performance Standards) approval, engine test: additional 3000 test cycles (a 0.5h). Switch: true (test) / false (no test)">
										<value>false</value>
									</ETOPS_switch>
									<engine_options description="Number of engine options for this aircraft">
										<value>2</value>
										<unit>1</unit>
										<lower_boundary>0</lower_boundary>
										<upper_boundary>10</upper_boundary>
									</engine_options>
								</aircraft_specs>
								<wind_tunnel_test description="Settings for wind tunnel test">
									<test_hours description="Number of wind tunnel hours in aircraft development">
										<value>15000</value>
										<unit>h</unit>
										<lower_boundary>0</lower_boundary>
										<upper_boundary>150000</upper_boundary>
									</test_hours>
								</wind_tunnel_test>
								<structural_test description="Settings for structural test">
									<test_cycles description="Number of tested flight cycles in aircraft development (twice the number of flight cycles for which the aircraft will be certified)">
										<value>160000</value>
										<unit>1</unit>
										<lower_boundary>0</lower_boundary>
										<upper_boundary>500000</upper_boundary>
									</test_cycles>
									<number_of_structural_test_aircraft description="Number of aircraft for structural tests">
										<value>2</value>
										<unit>1</unit>
										<lower_boundary>0</lower_boundary>
										<upper_boundary>10</upper_boundary>
									</number_of_structural_test_aircraft>
								</structural_test>
								<system_test description="Settings for system tests">
									<system_integration_test_hours description="Test hours at the system integration test rig">
										<value>5000</value>
										<unit>h</unit>
										<lower_boundary>0</lower_boundary>
										<upper_boundary>10000</upper_boundary>
									</system_integration_test_hours>
									<iron_bird_test_hours description="Test hours on the Iron-Bird test rig">
										<value>5000</value>
										<unit>h</unit>
										<lower_boundary>0</lower_boundary>
										<upper_boundary>10000</upper_boundary>
									</iron_bird_test_hours>
								</system_test>
								<engine_test description="Specify engine tests">
									<enable description="Switch to enable engine tests. Switch: true (engine tests on (only if new engine/s for aircraft has to be certified)) / false (engine tests off)">
										<value>true</value>
									</enable>
									<number_of_new_engines description="Number of new engine(s) to be certified">
										<value>1</value>
										<unit>1</unit>
										<lower_boundary>0</lower_boundary>
										<upper_boundary>10</upper_boundary>
									</number_of_new_engines>
									<number_of_test_engines description="Number of engine for test rig (approx. 5) and flight test (approx. 1)">
										<value>6</value>
										<unit>1</unit>
										<lower_boundary>0</lower_boundary>
										<upper_boundary>100</upper_boundary>
									</number_of_test_engines>
									<rig_test>
										<test_hours description="Test hours on the engine rig within aircraft development without/with ETOPS (Extended-range Twin-engine Operations Performance Standards) hours (s.inclETOPS)">
											<value>1500</value>
											<unit>h</unit>
											<lower_boundary>0</lower_boundary>
											<upper_boundary>15000</upper_boundary>
											<incl_ETOPS_switch description="Adds ETOPS (Extended-range Twin-engine Operations Performance Standards) certification in test hours. Switch: true (is included) / false (is not included)">
												<value>false</value>
											</incl_ETOPS_switch>
										</test_hours>
										<max_continuous_thrust_percentage description="Percentage of test hours on the engine rig with Maximum Continuous Thrust in aircraft development">
											<value>0.1</value>
											<unit>1</unit>
											<lower_boundary>0</lower_boundary>
											<upper_boundary>1</upper_boundary>
										</max_continuous_thrust_percentage>
									</rig_test>
									<flying_testbed description="Settings for the flying testbed ">
										<test_hours description="Test hours on flying testbed aircraft development">
											<value>225</value>
											<unit>h</unit>
											<lower_boundary>0</lower_boundary>
											<upper_boundary>1000</upper_boundary>
										</test_hours>
										<flying_testbed_engines description="Information about the engine at the flying_test_bed_engines (!), not to be tested engine">
											<engine_number description="Number of engines on flying testbed (without tested engine)">
												<value>3</value>
												<unit>1</unit>
												<lower_boundary>0</lower_boundary>
												<upper_boundary>20</upper_boundary>
											</engine_number>
											<flying_testbed_fuel_consumption_per_engine description="Fuel consumption of the flying testbed engines of (one!) engine in cruise flight">
												<value>3000</value>
												<unit>kg/h</unit>
												<lower_boundary>0</lower_boundary>
												<upper_boundary>10000</upper_boundary>
											</flying_testbed_fuel_consumption_per_engine>
										</flying_testbed_engines>
									</flying_testbed>
								</engine_test>
								<flight_test description="Settings for the flight tests">
									<test_hours description="Flight test hours in aircraft development for one / all Engine(s)-Option/s (s. incl_engine_options)">
										<value>2500</value>
										<unit>h</unit>
										<lower_boundary>0</lower_boundary>
										<upper_boundary>10000</upper_boundary>
										<incl_engine_options description="Defines if all engine options are included in tests. Switch: true (include all engine options) / false (only one engine)">
											<value>false</value>
										</incl_engine_options>
									</test_hours>
									<number_of_flight_test_aircraft description="Number of aircraft for flight tests">
										<value>6</value>
										<unit>1</unit>
										<lower_boundary>0</lower_boundary>
										<upper_boundary>10</upper_boundary>
									</number_of_flight_test_aircraft>
								</flight_test>
							</test_phase>
						</development_phase>
						<production_phase description="Settings for the calculation of the production phase">
							<production_mode description="Selects the production calculation mode. Selector: mode_0 (material mode) / mode_1 (main parts mode)">
								<value>mode_1</value>
							</production_mode>
							<primary_material_recycling_switch description="Enables primary material recycling. Switch: true (primary material will be recycled) / false (no recyling)">
								<value>true</value>
							</primary_material_recycling_switch>
							<calculate_recurring_costs_switch description="Switch for calculation of recurring costs. Switch: true (recurring costs will be calculated) / false (costs will be read from xml (old schema implemented, need to be adapted))">
								<value>true</value>
							</calculate_recurring_costs_switch>
							<number_produced_aircraft description="Number of produced aircraft per programm">
								<value>1500</value>
								<unit>1</unit>
								<lower_boundary>0</lower_boundary>
								<upper_boundary>10000</upper_boundary>
							</number_produced_aircraft>
						</production_phase>
						<operating_phase description="Settings for the calculation of the production phase">
							<calculate_maintenance_costs_switch description="Switch for calulation of maintencance costs. Switch: true (maintenance material costs will be calculated) / false (costs will be read from xml (old schema implemented, need to be adapted))">
								<value>true</value>
							</calculate_maintenance_costs_switch>
						</operating_phase>
						<end_of_life_phase description="Settings for the calculation of the end of life phase">
							<distance_to_end_of_life_site description="Distance to be flown to the demolition location">
								<value>1000</value>
								<unit>NM</unit>
								<lower_boundary>0</lower_boundary>
								<upper_boundary>10000</upper_boundary>
							</distance_to_end_of_life_site>
						</end_of_life_phase>
					</schaefer>
				</life_cycle_emissions_methods>
			</emission_calculation>
		</standard_strategy>
	</program_settings>
```
Additionally, the design mission taxi time is needed and read from the mission.xml:

```xml
<mission>
    <taxi_time_origin>
        <unit>s</unit>
        <value>540</value>
        <lower_boundary>0</lower_boundary>
        <upper_boundary>10000</upper_boundary>
    </taxi_time_origin>
    <taxi_time_destination>
        <unit>s</unit>
        <value>300</value>
        <lower_boundary>0</lower_boundary>
        <upper_boundary>10000</upper_boundary>
    </taxi_time_destination>
</mission>
```

And last but not least, the emissions provided by the submodule [mission_emissions](mission_emissions) will be read from ecological_assessment XML:

```xml
<ecological_data_file>
    <mission_emissions description="Results of mission emission calculation">
        <design_mission description="Results of design mission calculation">
            <emissions description="Emissions of design mission">
                <LTO_cycle description="Emissions of landing and takeoff cycle">
                    <CO2 description="LTO CO2 emissions of one design mission">
                        <value>2101.394</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </CO2>
                    <H2O description="LTO H2O emissions of one design mission">
                        <value>800.785</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </H2O>
                    <SO2 description="LTO SO2 emissions of one design mission">
                        <value>0.561</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </SO2>
                    <SO4 description="LTO SO4 emissions of one design mission">
                        <value>0.133</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </SO4>
                    <HC description="LTO HC emissions of one design mission">
                        <value>0.044</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </HC>
                    <CH4 description="LTO CH4 emissions of one design mission">
                        <value>0</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </CH4>
                    <CO description="LTO CO emissions of one design mission">
                        <value>2.855</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </CO>
                    <NOx description="LTO NOx emissions of one design mission">
                        <value>9.911</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </NOx>
                    <soot description="LTO Soot emissions of one design mission">
                        <value>0.015</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </soot>
                    <c_soot_LTO_max description="Maximum soot concentration during design mission LTO">
                        <value>1.794e-06</value>
                        <unit>1</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </c_soot_LTO_max>
                </LTO_cycle>
                <cruise description="Emissions of cruise phase">
                    <CO2 description="Cruise CO2 emissions of one design mission">
                        <value>53531.7</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </CO2>
                    <H2O description="Cruise H2O emissions of one design mission">
                        <value>20399.504</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </H2O>
                    <SO2 description="Cruise SO2 emissions of one design mission">
                        <value>14.28</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </SO2>
                    <SO4 description="Cruise SO4 emissions of one design mission">
                        <value>3.4</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </SO4>
                    <HC description="Cruise HC emissions of one design mission">
                        <value>0.939</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </HC>
                    <CH4 description="Cruise CH4 emissions of one design mission">
                        <value>0</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </CH4>
                    <CO description="Cruise CO emissions of one design mission">
                        <value>32.312</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </CO>
                    <NOx description="Cruise NOx emissions of one design mission">
                        <value>225.469</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </NOx>
                    <soot description="Cruise Soot emissions of one design mission">
                        <value>0.24</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </soot>
                </cruise>
            </emissions>
        </design_mission>
        <study_mission description="Results of study mission calculation">
            <emissions description="Emissions of study mission">
                <LTO_cycle description="Emissions of landing and takeoff cycle">
                    <CO2 description="LTO CO2 emissions of one study mission">
                        <value>2101.394</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </CO2>
                    <H2O description="LTO H2O emissions of one study mission">
                        <value>800.785</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </H2O>
                    <SO2 description="LTO SO2 emissions of one study mission">
                        <value>0.561</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </SO2>
                    <SO4 description="LTO SO4 emissions of one study mission">
                        <value>0.133</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </SO4>
                    <HC description="LTO HC emissions of one study mission">
                        <value>0.044</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </HC>
                    <CH4 description="LTO CH4 emissions of one study mission">
                        <value>0</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </CH4>
                    <CO description="LTO CO emissions of one study mission">
                        <value>2.855</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </CO>
                    <NOx description="LTO NOx emissions of one study mission">
                        <value>9.911</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </NOx>
                    <soot description="LTO Soot emissions of one study mission">
                        <value>0.015</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </soot>
                    <c_soot_LTO_max description="Maximum soot concentration during study mission LTO">
                        <value>1.794e-06</value>
                        <unit>1</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </c_soot_LTO_max>
                </LTO_cycle>
                <cruise description="Emissions of cruise phase">
                    <CO2 description="Cruise CO2 emissions of one study mission">
                        <value>53531.7</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </CO2>
                    <H2O description="Cruise H2O emissions of one study mission">
                        <value>20399.504</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </H2O>
                    <SO2 description="Cruise SO2 emissions of one study mission">
                        <value>14.28</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </SO2>
                    <SO4 description="Cruise SO4 emissions of one study mission">
                        <value>3.4</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </SO4>
                    <HC description="Cruise HC emissions of one study mission">
                        <value>0.939</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </HC>
                    <CH4 description="Cruise CH4 emissions of one study mission">
                        <value>0</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </CH4>
                    <CO description="Cruise CO emissions of one study mission">
                        <value>32.312</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </CO>
                    <NOx description="Cruise NOx emissions of one study mission">
                        <value>225.469</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </NOx>
                    <soot description="Cruise Soot emissions of one study mission">
                        <value>0.24</value>
                        <unit>kg</unit>
                        <lower_boundary>-1.797693135e+308</lower_boundary>
                        <upper_boundary>1.797693135e+308</upper_boundary>
                    </soot>
                </cruise>
            </emissions>
        </study_mission>
    </mission_emissions>
</ecological_data_file>
```
## Output-Data {#lca-schaefer-output}
The Method writes data to a CSV file in the _aircraft\_exchange\_file\_directory/ecologicalData_ folder containing emissions, energy demand, fuel demand and GWP100 for all processes. As described in [getting started](#getting-started), an HTML report including some plots will be generated.
