/**
 * \file schaeferReport.cpp
 * \author
 * \brief schaefer report implementation (html and tex)
 * \version 0.1
 * \date 2023-05-19
 *
 * @copyright Copyright (c) 2023
 *
 */
#include "../../../standard_strategy.h"
#include "../../../../toolinfo.h"
#include <vector>
#include <unitConversion/unitConversion.h>

void StandardStrategy::setHtmlBody_LCA_schaefer(const std::shared_ptr<RuntimeIO> &rtIO) {// cppcheck-suppress unusedFunction
        double totalCO2(0.);
        double totalHC(0.);
        double totalNOx(0.);
        double totalSO2(0.);
        double totalCO(0.);
        double totalH2O(0.);
        double totalCH4(0.);
        double totalPM10(0.);
        double totalN2O(0.);
        double totalPFC(0.);
        double totalNMVOC(0.);

        /* Table of Life cyle emissions */
        totalCO2 = theLifeCycleEmissionsSchaefer.theDevelopment.development_total.CO2/theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC
                + theLifeCycleEmissionsSchaefer.theProduction.production_total.CO2
                + theLifeCycleEmissionsSchaefer.theOperation.operation_total.CO2;
        if (theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.CO2 > 0.)
                totalCO2 += theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.CO2;

        totalHC = theLifeCycleEmissionsSchaefer.theDevelopment.development_total.HC/theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC
                + theLifeCycleEmissionsSchaefer.theProduction.production_total.HC
                + theLifeCycleEmissionsSchaefer.theOperation.operation_total.HC;
        if (theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.HC > 0.)
                totalHC += theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.HC;

        totalNOx = theLifeCycleEmissionsSchaefer.theDevelopment.development_total.NOx/theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC
                + theLifeCycleEmissionsSchaefer.theProduction.production_total.NOx
                + theLifeCycleEmissionsSchaefer.theOperation.operation_total.NOx;
        if (theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.NOx > 0.)
                totalNOx += theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.NOx;

        totalSO2 = theLifeCycleEmissionsSchaefer.theDevelopment.development_total.SO2/theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC
                + theLifeCycleEmissionsSchaefer.theProduction.production_total.SO2
                + theLifeCycleEmissionsSchaefer.theOperation.operation_total.SO2;
        if (theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.SO2 > 0.)
                totalSO2 += theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.SO2;

        totalCO = theLifeCycleEmissionsSchaefer.theDevelopment.development_total.CO/theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC
                + theLifeCycleEmissionsSchaefer.theProduction.production_total.CO
                + theLifeCycleEmissionsSchaefer.theOperation.operation_total.CO;
        if (theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.CO > 0.)
                totalCO += theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.CO;

        totalH2O = theLifeCycleEmissionsSchaefer.theDevelopment.development_total.H2O/theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC
                + theLifeCycleEmissionsSchaefer.theProduction.production_total.H2O
                + theLifeCycleEmissionsSchaefer.theOperation.operation_total.H2O;
        if (theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.H2O > 0.)
                totalH2O += theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.H2O;

        totalCH4 = theLifeCycleEmissionsSchaefer.theDevelopment.development_total.CH4/theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC
                + theLifeCycleEmissionsSchaefer.theProduction.production_total.CH4
                + theLifeCycleEmissionsSchaefer.theOperation.operation_total.CH4;
        if (theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.CH4 > 0.)
                totalCH4 += theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.CH4;

        totalPM10 = theLifeCycleEmissionsSchaefer.theDevelopment.development_total.PM10/theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC
                + theLifeCycleEmissionsSchaefer.theProduction.production_total.PM10
                + theLifeCycleEmissionsSchaefer.theOperation.operation_total.PM10;
        if (theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.PM10 > 0.)
                totalPM10 += theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.PM10;

        totalN2O = theLifeCycleEmissionsSchaefer.theDevelopment.development_total.N2O/theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC
                + theLifeCycleEmissionsSchaefer.theProduction.production_total.N2O
                + theLifeCycleEmissionsSchaefer.theOperation.operation_total.N2O;
        if (theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.N2O > 0.)
                totalN2O += theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.N2O;

        totalPFC = theLifeCycleEmissionsSchaefer.theDevelopment.development_total.PFC/theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC
                + theLifeCycleEmissionsSchaefer.theProduction.production_total.PFC
                + theLifeCycleEmissionsSchaefer.theOperation.operation_total.PFC;
        if (theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.PFC > 0.)
                totalPFC += theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.PFC;

        totalNMVOC = theLifeCycleEmissionsSchaefer.theDevelopment.development_total.NMVOC/theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC
                + theLifeCycleEmissionsSchaefer.theProduction.production_total.NMVOC
                + theLifeCycleEmissionsSchaefer.theOperation.operation_total.NMVOC;
        if (theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.NMVOC > 0.)
                totalNMVOC += theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.NMVOC;

        report_->htmlReportStream()
                << html::h2("Life Cycle Emissions")
                << "<br>"
                << html::h3("All Phases")
                << "<br>";
        report_->htmlReportStream() << html::table_begin({{"Parameter"},
                                        {"Development <font size=\"-1\">(scaled to 1 aircraft) </font>", "colspan=\"2\""},
                                        {"Production", "colspan=\"2\""}, {"Operation", "colspan=\"2\""},
                                        {"End of Life", "colspan=\"2\""}})
        << html::table_row("", "[t]", "[%]", "[t]", "[%]", "[t]", "[%]", "[t]", "[%]")
        << html::table_row("CO2",
                theLifeCycleEmissionsSchaefer.theDevelopment.development_total.CO2 / theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC / 1000,
                theLifeCycleEmissionsSchaefer.theDevelopment.development_total.CO2 / theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC / totalCO2 * 100,
                theLifeCycleEmissionsSchaefer.theProduction.production_total.CO2 / 1000,
                theLifeCycleEmissionsSchaefer.theProduction.production_total.CO2 / totalCO2 * 100,
                theLifeCycleEmissionsSchaefer.theOperation.operation_total.CO2 / 1000,
                theLifeCycleEmissionsSchaefer.theOperation.operation_total.CO2 / totalCO2 * 100,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.CO2 / 1000,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.CO2 / totalCO2 * 100)
        << html::table_row("H2O",
                theLifeCycleEmissionsSchaefer.theDevelopment.development_total.H2O / theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC / 1000,
                theLifeCycleEmissionsSchaefer.theDevelopment.development_total.H2O / theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC / totalH2O * 100,
                theLifeCycleEmissionsSchaefer.theProduction.production_total.H2O / 1000,
                theLifeCycleEmissionsSchaefer.theProduction.production_total.H2O / totalH2O * 100,
                theLifeCycleEmissionsSchaefer.theOperation.operation_total.H2O / 1000,
                theLifeCycleEmissionsSchaefer.theOperation.operation_total.H2O / totalH2O * 100,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.H2O / 1000,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.H2O / totalH2O * 100)
        << html::table_row("SO2",
                theLifeCycleEmissionsSchaefer.theDevelopment.development_total.SO2 / theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC / 1000,
                theLifeCycleEmissionsSchaefer.theDevelopment.development_total.SO2 / theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC / totalSO2 * 100,
                theLifeCycleEmissionsSchaefer.theProduction.production_total.SO2 / 1000,
                theLifeCycleEmissionsSchaefer.theProduction.production_total.SO2 / totalSO2 * 100,
                theLifeCycleEmissionsSchaefer.theOperation.operation_total.SO2 / 1000,
                theLifeCycleEmissionsSchaefer.theOperation.operation_total.SO2 / totalSO2 * 100,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.SO2 / 1000,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.SO2 / totalSO2 * 100)
        << html::table_row("HC",
                theLifeCycleEmissionsSchaefer.theDevelopment.development_total.HC / theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC / 1000,
                theLifeCycleEmissionsSchaefer.theDevelopment.development_total.HC / theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC / totalHC * 100,
                theLifeCycleEmissionsSchaefer.theProduction.production_total.HC / 1000,
                theLifeCycleEmissionsSchaefer.theProduction.production_total.HC / totalHC * 100,
                theLifeCycleEmissionsSchaefer.theOperation.operation_total.HC / 1000,
                theLifeCycleEmissionsSchaefer.theOperation.operation_total.HC / totalHC * 100,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.HC / 1000,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.HC / totalHC * 100)
        << html::table_row("CH4",
                theLifeCycleEmissionsSchaefer.theDevelopment.development_total.CH4 / theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC / 1000,
                theLifeCycleEmissionsSchaefer.theDevelopment.development_total.CH4 / theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC / totalCH4 * 100,
                theLifeCycleEmissionsSchaefer.theProduction.production_total.CH4 / 1000,
                theLifeCycleEmissionsSchaefer.theProduction.production_total.CH4 / totalCH4 * 100,
                theLifeCycleEmissionsSchaefer.theOperation.operation_total.CH4 / 1000,
                theLifeCycleEmissionsSchaefer.theOperation.operation_total.CH4 / totalCH4 * 100,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.CH4 / 1000,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.CH4 / totalCH4 * 100)
        << html::table_row("NOx",
                theLifeCycleEmissionsSchaefer.theDevelopment.development_total.NOx / theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC / 1000,
                theLifeCycleEmissionsSchaefer.theDevelopment.development_total.NOx / theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC / totalNOx * 100,
                theLifeCycleEmissionsSchaefer.theProduction.production_total.NOx / 1000,
                theLifeCycleEmissionsSchaefer.theProduction.production_total.NOx / totalNOx * 100,
                theLifeCycleEmissionsSchaefer.theOperation.operation_total.NOx / 1000,
                theLifeCycleEmissionsSchaefer.theOperation.operation_total.NOx / totalNOx * 100,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.NOx / 1000,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.NOx / totalNOx * 100)
        << html::table_row("CO",
                theLifeCycleEmissionsSchaefer.theDevelopment.development_total.CO / theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC / 1000,
                theLifeCycleEmissionsSchaefer.theDevelopment.development_total.CO / theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC / totalCO * 100,
                theLifeCycleEmissionsSchaefer.theProduction.production_total.CO / 1000,
                theLifeCycleEmissionsSchaefer.theProduction.production_total.CO / totalCO * 100,
                theLifeCycleEmissionsSchaefer.theOperation.operation_total.CO / 1000,
                theLifeCycleEmissionsSchaefer.theOperation.operation_total.CO / totalCO * 100,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.CO / 1000,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.CO / totalCO * 100)
        << html::table_row("PM10",
                theLifeCycleEmissionsSchaefer.theDevelopment.development_total.PM10 / theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC / 1000,
                theLifeCycleEmissionsSchaefer.theDevelopment.development_total.PM10 / theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC / totalPM10 * 100,
                theLifeCycleEmissionsSchaefer.theProduction.production_total.PM10 / 1000,
                theLifeCycleEmissionsSchaefer.theProduction.production_total.PM10 / totalPM10 * 100,
                theLifeCycleEmissionsSchaefer.theOperation.operation_total.PM10 / 1000,
                theLifeCycleEmissionsSchaefer.theOperation.operation_total.PM10 / totalPM10 * 100,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.PM10 / 1000,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.PM10 / totalPM10 * 100)
        << html::table_row("N2O",
                theLifeCycleEmissionsSchaefer.theDevelopment.development_total.N2O / theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC / 1000,
                theLifeCycleEmissionsSchaefer.theDevelopment.development_total.N2O / theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC / totalN2O * 100,
                theLifeCycleEmissionsSchaefer.theProduction.production_total.N2O / 1000,
                theLifeCycleEmissionsSchaefer.theProduction.production_total.N2O / totalN2O * 100,
                theLifeCycleEmissionsSchaefer.theOperation.operation_total.N2O / 1000,
                theLifeCycleEmissionsSchaefer.theOperation.operation_total.N2O / totalN2O * 100,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.N2O / 1000,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.N2O / totalN2O * 100)
        << html::table_row("PFC",
                theLifeCycleEmissionsSchaefer.theDevelopment.development_total.PFC / theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC / 1000,
                theLifeCycleEmissionsSchaefer.theDevelopment.development_total.PFC / theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC / totalPFC * 100,
                theLifeCycleEmissionsSchaefer.theProduction.production_total.PFC / 1000,
                theLifeCycleEmissionsSchaefer.theProduction.production_total.PFC / totalPFC * 100,
                theLifeCycleEmissionsSchaefer.theOperation.operation_total.PFC / 1000,
                theLifeCycleEmissionsSchaefer.theOperation.operation_total.PFC / totalPFC * 100,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.PFC / 1000,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.PFC / totalPFC * 100)
        << html::table_row("NMVOC",
                theLifeCycleEmissionsSchaefer.theDevelopment.development_total.NMVOC / theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC / 1000,
                theLifeCycleEmissionsSchaefer.theDevelopment.development_total.NMVOC / theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.producedAC / totalNMVOC * 100,
                theLifeCycleEmissionsSchaefer.theProduction.production_total.NMVOC / 1000,
                theLifeCycleEmissionsSchaefer.theProduction.production_total.NMVOC / totalNMVOC * 100,
                theLifeCycleEmissionsSchaefer.theOperation.operation_total.NMVOC / 1000,
                theLifeCycleEmissionsSchaefer.theOperation.operation_total.NMVOC / totalNMVOC * 100,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.NMVOC / 1000,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.NMVOC / totalNMVOC * 100)
        << "</tbody>" << "\n"
        << html::table_end;

        /* Development Emissions*/
        if (theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.developmentEmissionSetting != "mode_0") {
                report_->htmlReportStream() << html::h3("Test phase") << "<br>";
                /* Table test phase */
                if (theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.developmentEmissionSetting != "mode_0") {
                        report_->htmlReportStream() << html::table_begin({{"Parameter"}, {"[kg]"}, {"[%]"}})
                        << html::table_row("CO2",
                                        Rounding(theLifeCycleEmissionsSchaefer.theDevelopment.test_total.CO2, 3),
                                        Rounding(theLifeCycleEmissionsSchaefer.theDevelopment.test_total.CO2/totalCO2*100, 2))
                        << html::table_row("H2O",
                                        Rounding(theLifeCycleEmissionsSchaefer.theDevelopment.test_total.H2O, 3),
                                        Rounding(theLifeCycleEmissionsSchaefer.theDevelopment.test_total.H2O/totalH2O*100, 2))
                        << html::table_row("SO2",
                                        Rounding(theLifeCycleEmissionsSchaefer.theDevelopment.test_total.SO2, 3),
                                        Rounding(theLifeCycleEmissionsSchaefer.theDevelopment.test_total.SO2/totalSO2*100, 2))
                        << html::table_row("HC",
                                        Rounding(theLifeCycleEmissionsSchaefer.theDevelopment.test_total.HC, 3),
                                        Rounding(theLifeCycleEmissionsSchaefer.theDevelopment.test_total.HC/totalHC*100, 2))
                        << html::table_row("CO",
                                        Rounding(theLifeCycleEmissionsSchaefer.theDevelopment.test_total.CO, 3),
                                        Rounding(theLifeCycleEmissionsSchaefer.theDevelopment.test_total.CO/totalCO*100, 2))
                        << html::table_row("NOx",
                                        Rounding(theLifeCycleEmissionsSchaefer.theDevelopment.test_total.NOx, 3),
                                        Rounding(theLifeCycleEmissionsSchaefer.theDevelopment.test_total.NOx/totalNOx*100, 2))
                        << html::table_row("PM10",
                                        Rounding(theLifeCycleEmissionsSchaefer.theDevelopment.test_total.PM10, 3),
                                        Rounding(theLifeCycleEmissionsSchaefer.theDevelopment.test_total.PM10/totalPM10*100, 2))
                        << html::table_row("CH4",
                                        Rounding(theLifeCycleEmissionsSchaefer.theDevelopment.test_total.CH4, 3),
                                        Rounding(theLifeCycleEmissionsSchaefer.theDevelopment.test_total.CH4/totalCH4*100, 2))
                        << html::table_row("N2O",
                                        Rounding(theLifeCycleEmissionsSchaefer.theDevelopment.test_total.N2O, 3),
                                        Rounding(theLifeCycleEmissionsSchaefer.theDevelopment.test_total.N2O/totalN2O*100, 2))
                        << html::table_row("PFC",
                                        Rounding(theLifeCycleEmissionsSchaefer.theDevelopment.test_total.PFC, 3),
                                        Rounding(theLifeCycleEmissionsSchaefer.theDevelopment.test_total.PFC/totalPFC*100, 2))
                        << html::table_row("NMVOC",
                                        Rounding(theLifeCycleEmissionsSchaefer.theDevelopment.test_total.NMVOC, 3),
                                        Rounding(theLifeCycleEmissionsSchaefer.theDevelopment.test_total.NMVOC/totalNMVOC*100, 2))
                       << html::table_end << "<br>";
                }
        }
        report_->htmlReportStream()
        << "<br>" << "\n"<< "<br>" << "\n"
        << html::image(relativePath(rtIO->getPlotDir()+"/", rtIO->getReportDir()) + std::string(TOOL_NAME) + "_inflightEmissions.svg", "height=\"400px\"")
        << html::image(relativePath(rtIO->getPlotDir()+"/", rtIO->getReportDir()) + std::string(TOOL_NAME) + "_lifeCycleEmissions.svg", "height=\"400px\"");
}

void StandardStrategy::setTexBody_LCA_schaefer(const std::shared_ptr<RuntimeIO> &rtIO) {
        // TODO
}

void StandardStrategy::generateInflightEmissionsCSV_schaefer() {
    std::string csvFileName(rtIO_->acxmlAccess.parent_path().string() + "/ecologicalData/ecological_assessment_inflightEmissions.csv");
    std::ofstream csv;
    csv.open(csvFileName.c_str());
    if (!csv) {
        myRuntimeInfo->err << csvFileName + " could not be opened!" << std::endl;
        exit(1);
    } else {
        if (theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.developmentEmissionSetting != "mode_0") {
            double totalCO2 = theLifeCycleEmissionsSchaefer.theDevelopment.test_total.CO2 + theStudyMission.LTO_Total.CO2 + theStudyMission.Cruise_Total.CO2;
            double totalHC = theLifeCycleEmissionsSchaefer.theDevelopment.test_total.HC + theStudyMission.LTO_Total.HC + theStudyMission.Cruise_Total.HC;
            double totalNOx = theLifeCycleEmissionsSchaefer.theDevelopment.test_total.NOx + theStudyMission.LTO_Total.NOx + theStudyMission.Cruise_Total.NOx;
            double totalSO2 = theLifeCycleEmissionsSchaefer.theDevelopment.test_total.SO2 + theStudyMission.LTO_Total.SO2 + theStudyMission.Cruise_Total.SO2;
            double totalCO = theLifeCycleEmissionsSchaefer.theDevelopment.test_total.CO + theStudyMission.LTO_Total.CO + theStudyMission.Cruise_Total.CO;
            double totalH2O = theLifeCycleEmissionsSchaefer.theDevelopment.test_total.H2O + theStudyMission.LTO_Total.H2O + theStudyMission.Cruise_Total.H2O;
            double totalPM10 = theLifeCycleEmissionsSchaefer.theDevelopment.test_total.PM10 + theStudyMission.LTO_Total.soot
                               + theStudyMission.Cruise_Total.soot;
            csv << "# " + csvFileName << std::endl;
            /* Adjust data structure: **/
            csv << "# (1)Parameter, (2)Test, (3)LTO, (4)Cruise " << std::endl;
            csv << "CO2; " << theLifeCycleEmissionsSchaefer.theDevelopment.test_total.CO2 / totalCO2 * 100 << "; " << theStudyMission.LTO_Total.CO2 / totalCO2 * 100 << "; " <<
                 theStudyMission.Cruise_Total.CO2 / totalCO2 * 100 << ";" << std::endl;
            csv << "H2O; " << theLifeCycleEmissionsSchaefer.theDevelopment.test_total.H2O / totalH2O * 100 << "; " << theStudyMission.LTO_Total.H2O / totalH2O * 100 << "; " <<
                 theStudyMission.Cruise_Total.H2O / totalH2O * 100 << ";" << std::endl;
            csv << "SO2; " << theLifeCycleEmissionsSchaefer.theDevelopment.test_total.SO2 / totalSO2 * 100 << "; " << theStudyMission.LTO_Total.SO2 / totalSO2 * 100 << "; " <<
                 theStudyMission.Cruise_Total.SO2 / totalSO2 * 100 << ";" << std::endl;
            csv << "HC; " << theLifeCycleEmissionsSchaefer.theDevelopment.test_total.HC / totalHC * 100 << "; " << theStudyMission.LTO_Total.HC / totalHC * 100 << "; " <<
                 theStudyMission.Cruise_Total.HC / totalHC * 100 << ";" << std::endl;
            csv << "CO; " << theLifeCycleEmissionsSchaefer.theDevelopment.test_total.CO / totalCO * 100 << "; " << theStudyMission.LTO_Total.CO / totalCO * 100 << "; " <<
                 theStudyMission.Cruise_Total.CO / totalCO * 100 << ";" << std::endl;
            csv << "NOx; " << theLifeCycleEmissionsSchaefer.theDevelopment.test_total.NOx / totalNOx * 100 << "; " << theStudyMission.LTO_Total.NOx / totalNOx * 100 << "; " <<
                 theStudyMission.Cruise_Total.NOx / totalNOx * 100 << ";" << std::endl;
            csv << "PM10; " << theLifeCycleEmissionsSchaefer.theDevelopment.test_total.PM10 / totalPM10 * 100 << "; "<< theStudyMission.LTO_Total.soot / totalPM10 * 100 << "; " <<
                 theStudyMission.Cruise_Total.soot / totalPM10 * 100 << ";" << std::endl;
        } else {
            double totalCO2 = theStudyMission.LTO_Total.CO2 + theStudyMission.Cruise_Total.CO2;
            double totalHC = theStudyMission.LTO_Total.HC + theStudyMission.Cruise_Total.HC;
            double totalNOx = theStudyMission.LTO_Total.NOx + theStudyMission.Cruise_Total.NOx;
            double totalSO2 = theStudyMission.LTO_Total.SO2 + theStudyMission.Cruise_Total.SO2;
            double totalCO = theStudyMission.LTO_Total.CO + theStudyMission.Cruise_Total.CO;
            double totalH2O = theStudyMission.LTO_Total.H2O + theStudyMission.Cruise_Total.H2O;
            double totalPM10 = theStudyMission.LTO_Total.soot + theStudyMission.Cruise_Total.soot;
            csv << "# " + csvFileName << std::endl;
            /* Adjust data structure: **/
            csv << "# (1)Parameter, (2)LTO, (3)Cruise " << std::endl;
            csv << "CO2; " << theStudyMission.LTO_Total.CO2 / totalCO2 * 100 << "; "
                 << theStudyMission.Cruise_Total.CO2 / totalCO2 * 100 << ";" << std::endl;
            csv << "SO2; " << theStudyMission.LTO_Total.SO2 / totalSO2 * 100 << "; "
                 << theStudyMission.Cruise_Total.SO2 / totalSO2 * 100 << ";" << std::endl;
            csv << "H2O; " << theStudyMission.LTO_Total.H2O / totalH2O * 100 << "; "
                 << theStudyMission.Cruise_Total.H2O / totalH2O * 100 << ";" << std::endl;
            csv << "HC; " << theStudyMission.LTO_Total.HC / totalHC * 100 << "; "
                 << theStudyMission.Cruise_Total.HC / totalHC * 100 << ";" << std::endl;
            csv << "CO; " << theStudyMission.LTO_Total.CO / totalCO * 100 << "; "
                 << theStudyMission.Cruise_Total.CO / totalCO * 100 << ";" << std::endl;
            csv << "NOx; " << theStudyMission.LTO_Total.NOx / totalNOx * 100 << "; "
                 << theStudyMission.Cruise_Total.NOx / totalNOx * 100 << ";" << std::endl;
            csv << "PM10; " << theStudyMission.LTO_Total.soot / totalPM10 * 100 << "; "
                 << theStudyMission.Cruise_Total.soot / totalPM10 * 100 << ";" << std::endl;
        }
        csv.close();
    }
}

void StandardStrategy::generateLifeCycleEmissionsCSV_schaefer() {
     std::ofstream csv;
     std::string csvDataFile(rtIO_->acxmlAccess.parent_path().string() + "/ecologicalData/ecological_assessment_lifeCycleEmissions.csv");
     csv.open(csvDataFile.c_str());
     if (!csv) {
          myRuntimeInfo->err << csvDataFile + "could not be opened!" << std::endl;
          exit(1);
     } else {
          std::string del("; ");
          csv << "# " + csvDataFile << std::endl;
          csv << "# all emission data in [kg]; Energy in [MJ], AC Fuel in [kg] (without logistics fuel, only fuel of the investigated AC)" << std::endl;
          /* Adjust data structure: **/
          csv << std::endl << std::endl;
          csv << "# Development Phase (NOT for one AC but for total Development phase) " << std::endl;
          csv << "# (1)EmissionName; (2)CO2; (3)H2O; (4)NOx; (5)CO; (6)SO2; (7)CH4; (8)PM10; (9)N2O; (10)PFC; (11)NMVOC; (12)HC; (13) Energy; (14) AC Fuel; (15) GWP100" <<
             std::endl;//GWP after CML2015, IPCC value
          csv << "Development_total" << del << theLifeCycleEmissionsSchaefer.theDevelopment.development_total.CO2
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.development_total.H2O << del << theLifeCycleEmissionsSchaefer.theDevelopment.development_total.NOx
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.development_total.CO
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.development_total.SO2 << del << theLifeCycleEmissionsSchaefer.theDevelopment.development_total.CH4
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.development_total.PM10<< del << theLifeCycleEmissionsSchaefer.theDevelopment.development_total.N2O
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.development_total.PFC << del << theLifeCycleEmissionsSchaefer.theDevelopment.development_total.NMVOC
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.development_total.HC << del <<  theLifeCycleEmissionsSchaefer.theDevelopment.development_total.CED
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.fuel_total << del
               << theLifeCycleEmissionsSchaefer.theDevelopment.development_total.CO2 + theLifeCycleEmissionsSchaefer.theDevelopment.development_total.CH4 * 25 << std::endl;
          csv << "Engineering_total" << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_total.CO2
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_total.H2O
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_total.NOx << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_total.CO
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_total.SO2 << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_total.CH4
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_total.PM10 << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_total.N2O
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_total.PFC << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_total.NMVOC
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_total.HC << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_total.CED
               << del << 0.
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_total.CO2 + theLifeCycleEmissionsSchaefer.theDevelopment.engineering_total.CH4 * 25 << std::endl;
          csv << "EngineeringElec" << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_elec.CO2
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_elec.H2O
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_elec.NOx << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_elec.CO
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_elec.SO2 << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_elec.CH4
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_elec.PM10 << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_elec.N2O
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_elec.PFC << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_elec.NMVOC
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_elec.HC << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_elec.CED << del << 0.
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_elec.CO2 + theLifeCycleEmissionsSchaefer.theDevelopment.engineering_elec.CH4 * 25 << std::endl;
          csv << "EngineeringHeat" << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_heat.CO2
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_heat.H2O
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_heat.NOx << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_heat.CO
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_heat.SO2 << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_heat.CH4
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_heat.PM10 << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_heat.N2O
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_heat.PFC << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_heat.NMVOC
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_heat.HC << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_heat.CED
               << del << 0.
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineering_heat.CO2 + theLifeCycleEmissionsSchaefer.theDevelopment.engineering_heat.CH4 * 25 << std::endl;
          /*csv << "TestFueLProduction" << del << testFuelProduction.CO2 << del << testFuelProduction.H2O << del <<
               testFuelProduction.NOx << del << testFuelProduction.CO << del << testFuelProduction.SO2 << del <<
               testFuelProduction.CH4 << del << testFuelProduction.PM10 << del << testFuelProduction.N2O << del <<
               testFuelProduction.PFC << del << testFuelProduction.NMVOC << del << testFuelProduction.HC << std::endl;*/
          csv << "Test_total" << del << theLifeCycleEmissionsSchaefer.theDevelopment.test_total.CO2 << del << theLifeCycleEmissionsSchaefer.theDevelopment.test_total.H2O << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.test_total.NOx << del << theLifeCycleEmissionsSchaefer.theDevelopment.test_total.CO << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.test_total.SO2 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.test_total.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.test_total.PM10 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.test_total.N2O << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.test_total.PFC << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.test_total.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.test_total.HC << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.test_total.CED << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.testResources.fuel_totalTest << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.test_total.CO2 + theLifeCycleEmissionsSchaefer.theDevelopment.test_total.CH4 * 25 << std::endl;
          csv << "WindTunnelTests" << del << theLifeCycleEmissionsSchaefer.theDevelopment.windtunnelTest.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.windtunnelTest.H2O << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.windtunnelTest.NOx << del << theLifeCycleEmissionsSchaefer.theDevelopment.windtunnelTest.CO << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.windtunnelTest.SO2 << del << theLifeCycleEmissionsSchaefer.theDevelopment.windtunnelTest.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.windtunnelTest.PM10 << del << theLifeCycleEmissionsSchaefer.theDevelopment.windtunnelTest.N2O << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.windtunnelTest.PFC << del << theLifeCycleEmissionsSchaefer.theDevelopment.windtunnelTest.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.windtunnelTest.HC << del << theLifeCycleEmissionsSchaefer.theDevelopment.windtunnelTest.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.windtunnelTest.CO2 + theLifeCycleEmissionsSchaefer.theDevelopment.windtunnelTest.CH4 * 25 << std::endl;
          csv << "StructureTests" << del << theLifeCycleEmissionsSchaefer.theDevelopment.structureTest.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.structureTest.H2O << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.structureTest.NOx << del << theLifeCycleEmissionsSchaefer.theDevelopment.structureTest.CO << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.structureTest.SO2 << del << theLifeCycleEmissionsSchaefer.theDevelopment.structureTest.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.structureTest.PM10 << del << theLifeCycleEmissionsSchaefer.theDevelopment.structureTest.N2O << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.structureTest.PFC << del << theLifeCycleEmissionsSchaefer.theDevelopment.structureTest.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.structureTest.HC << del << theLifeCycleEmissionsSchaefer.theDevelopment.structureTest.CED << del << 0. <<  del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.structureTest.CO2 + theLifeCycleEmissionsSchaefer.theDevelopment.structureTest.CH4 * 25 << std::endl;
          csv << "SystemTests" << del << theLifeCycleEmissionsSchaefer.theDevelopment.systemTest.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.systemTest.H2O << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.systemTest.NOx << del << theLifeCycleEmissionsSchaefer.theDevelopment.systemTest.CO << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.systemTest.SO2 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.systemTest.CH4 << del << theLifeCycleEmissionsSchaefer.theDevelopment.systemTest.PM10 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.systemTest.N2O << del << theLifeCycleEmissionsSchaefer.theDevelopment.systemTest.PFC << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.systemTest.NMVOC << del << theLifeCycleEmissionsSchaefer.theDevelopment.systemTest.HC << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.systemTest.CED  << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.systemTest.CO2 + theLifeCycleEmissionsSchaefer.theDevelopment.systemTest.CH4 * 25 << std::endl;
          csv << "GroundTests (incl. Fuel Prod.)" << del << theLifeCycleEmissionsSchaefer.theDevelopment.groundTest.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.groundTest.H2O << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.groundTest.NOx << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.groundTest.CO << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.groundTest.SO2 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.groundTest.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.groundTest.PM10 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.groundTest.N2O << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.groundTest.PFC << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.groundTest.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.groundTest.HC << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.groundTest.CED << del <<
               theDesignMission.m_fuel_Taxi *theLifeCycleEmissionsSchaefer.theDevelopment.taxiTestFactor << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.groundTest.CO2 + theLifeCycleEmissionsSchaefer.theDevelopment.groundTest.CH4 * 25 << std::endl;
          if (theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.doEngineTest) {
               csv << "EngineTests " << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineTest.CO2 << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.engineTest.H2O << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.engineTest.NOx << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.engineTest.CO << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineTest.SO2 << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.engineTest.CH4 << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineTest.PM10 << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.engineTest.N2O << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineTest.PFC << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.engineTest.NMVOC << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineTest.HC << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.engineTest.CED << del << theLifeCycleEmissionsSchaefer.theDevelopment.testResources.fuel_engineTest_total << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.engineTest.CO2 + theLifeCycleEmissionsSchaefer.theDevelopment.engineTest.CH4 * 25 << std::endl;
          }
          csv << "FlightTest (incl. Fuel Prod.)" << del << theLifeCycleEmissionsSchaefer.theDevelopment.flightTest.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.flightTest.H2O << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.flightTest.NOx << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.flightTest.CO << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.flightTest.SO2 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.flightTest.CH4 << del << theLifeCycleEmissionsSchaefer.theDevelopment.flightTest.PM10 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.flightTest.N2O << del << theLifeCycleEmissionsSchaefer.theDevelopment.flightTest.PFC << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.flightTest.NMVOC << del << theLifeCycleEmissionsSchaefer.theDevelopment.flightTest.HC << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.flightTest.CED << del << theLifeCycleEmissionsSchaefer.theDevelopment.testResources.fuel_flightTest << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.flightTest.CO2 + theLifeCycleEmissionsSchaefer.theDevelopment.flightTest.CH4 * 25 << std::endl;
          csv << "TestACProduction" << del << theLifeCycleEmissionsSchaefer.theDevelopment.testACProduction.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.testACProduction.H2O << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.testACProduction.NOx << del << theLifeCycleEmissionsSchaefer.theDevelopment.testACProduction.CO << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.testACProduction.SO2 << del << theLifeCycleEmissionsSchaefer.theDevelopment.testACProduction.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.testACProduction.PM10 << del << theLifeCycleEmissionsSchaefer.theDevelopment.testACProduction.N2O << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.testACProduction.PFC << del << theLifeCycleEmissionsSchaefer.theDevelopment.testACProduction.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.testACProduction.HC << del << theLifeCycleEmissionsSchaefer.theDevelopment.testACProduction.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.testACProduction.CO2 + theLifeCycleEmissionsSchaefer.theDevelopment.testACProduction.CH4 * 25 << std::endl;
          if (theLifeCycleEmissionsSchaefer.schaeferIOData_->configuration.doEngineTest) {
               csv << "TestEngineProduction" << del << theLifeCycleEmissionsSchaefer.theDevelopment.testEngineProduction.CO2 << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.testEngineProduction.H2O << del << theLifeCycleEmissionsSchaefer.theDevelopment.testEngineProduction.NOx << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.testEngineProduction.CO << del << theLifeCycleEmissionsSchaefer.theDevelopment.testEngineProduction.SO2 << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.testEngineProduction.CH4 << del << theLifeCycleEmissionsSchaefer.theDevelopment.testEngineProduction.PM10 << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.testEngineProduction.N2O << del << theLifeCycleEmissionsSchaefer.theDevelopment.testEngineProduction.PFC << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.testEngineProduction.NMVOC << del << theLifeCycleEmissionsSchaefer.theDevelopment.testEngineProduction.HC << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.testEngineProduction.CED << del << 0. << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.testEngineProduction.CO2 + theLifeCycleEmissionsSchaefer.theDevelopment.testEngineProduction.CH4 * 25 << std::endl;
          }
          csv << std::endl << std::endl;
          csv << "# Production Phase " << std::endl;
          csv << "# (1)EmissionName; (2)CO2; (3)H2O; (4)NOx; (5)CO; (6)SO2; (7)CH4; (8)PM10; (9)N2O; (10)PFC;"
                    " (11)NMVOC; (12)HC; (13) Energy; (14) AC Fuel; (15) GWP100" << std::endl;
          csv << "Production_total" << del << theLifeCycleEmissionsSchaefer.theProduction.production_total.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.production_total.H2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.production_total.NOx << del << theLifeCycleEmissionsSchaefer.theProduction.production_total.CO << del <<
               theLifeCycleEmissionsSchaefer.theProduction.production_total.SO2 << del << theLifeCycleEmissionsSchaefer.theProduction.production_total.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.production_total.PM10 << del << theLifeCycleEmissionsSchaefer.theProduction.production_total.N2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.production_total.PFC << del << theLifeCycleEmissionsSchaefer.theProduction.production_total.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.production_total.HC << del << theLifeCycleEmissionsSchaefer.theProduction.production_total.CED << del <<
               theLifeCycleEmissionsSchaefer.theProduction.testFlightFuel  << del <<
               theLifeCycleEmissionsSchaefer.theProduction.production_total.CO2 + theLifeCycleEmissionsSchaefer.theProduction.production_total.CH4 * 25 << std::endl;
          csv << "MaterialProduction" << del << theLifeCycleEmissionsSchaefer.theProduction.materialProduction_total.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProduction_total.H2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProduction_total.NOx << del << theLifeCycleEmissionsSchaefer.theProduction.materialProduction_total.CO << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProduction_total.SO2 << del << theLifeCycleEmissionsSchaefer.theProduction.materialProduction_total.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProduction_total.PM10 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProduction_total.N2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProduction_total.PFC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProduction_total.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProduction_total.HC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProduction_total.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProduction_total.CO2 + theLifeCycleEmissionsSchaefer.theProduction.materialProduction_total.CH4 * 25
               << std::endl;
          csv << "MaterialProcessing" << del << theLifeCycleEmissionsSchaefer.theProduction.materialProcessing_total.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProcessing_total.H2O << del << theLifeCycleEmissionsSchaefer.theProduction.materialProcessing_total.NOx << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProcessing_total.CO << del << theLifeCycleEmissionsSchaefer.theProduction.materialProcessing_total.SO2 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProcessing_total.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProcessing_total.PM10 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProcessing_total.N2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProcessing_total.PFC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProcessing_total.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProcessing_total.HC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProcessing_total.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProcessing_total.CO2 + theLifeCycleEmissionsSchaefer.theProduction.materialProcessing_total.CH4 * 25
               << std::endl;
          csv << "LabourProduction_total" << del << theLifeCycleEmissionsSchaefer.theProduction.labourProduction_total.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProduction_total.H2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProduction_total.NOx << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProduction_total.CO << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProduction_total.SO2 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProduction_total.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProduction_total.PM10 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProduction_total.N2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProduction_total.PFC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProduction_total.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProduction_total.HC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProduction_total.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProduction_total.CO2 + theLifeCycleEmissionsSchaefer.theProduction.labourProduction_total.CH4 * 25 << std::endl;
          csv << "LabourProduction_elec" << del << theLifeCycleEmissionsSchaefer.theProduction.labourProduction_elec.CO2 << del <<
          theLifeCycleEmissionsSchaefer.theProduction.labourProduction_elec.H2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProduction_elec.NOx << del << theLifeCycleEmissionsSchaefer.theProduction.labourProduction_elec.CO << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProduction_elec.SO2 << del << theLifeCycleEmissionsSchaefer.theProduction.labourProduction_elec.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProduction_elec.PM10 << del << theLifeCycleEmissionsSchaefer.theProduction.labourProduction_elec.N2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProduction_elec.PFC << del << theLifeCycleEmissionsSchaefer.theProduction.labourProduction_elec.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProduction_elec.HC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProduction_elec.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProduction_elec.CO2 + theLifeCycleEmissionsSchaefer.theProduction.labourProduction_elec.CH4 * 25 << std::endl;
          csv << "LabourProduction_heat" << del << theLifeCycleEmissionsSchaefer.theProduction.labourProduction_heat.CO2 << del <<
          theLifeCycleEmissionsSchaefer.theProduction.labourProduction_heat.H2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProduction_heat.NOx << del << theLifeCycleEmissionsSchaefer.theProduction.labourProduction_heat.CO << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProduction_heat.SO2 << del << theLifeCycleEmissionsSchaefer.theProduction.labourProduction_heat.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProduction_heat.PM10 << del << theLifeCycleEmissionsSchaefer.theProduction.labourProduction_heat.N2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProduction_heat.PFC << del << theLifeCycleEmissionsSchaefer.theProduction.labourProduction_heat.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProduction_heat.HC << del << theLifeCycleEmissionsSchaefer.theProduction.labourProduction_heat.CED << del <<
               0. << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProduction_heat.CO2 + theLifeCycleEmissionsSchaefer.theProduction.labourProduction_heat.CH4 * 25 << std::endl;
          csv << "FinalAssembly_total" << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_total.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_total.H2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_total.NOx << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_total.CO << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_total.SO2 << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_total.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_total.PM10 << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_total.N2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_total.PFC << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_total.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_total.HC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_total.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_total.CO2 + theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_total.CH4 * 25 << std::endl;
          csv << "FinalAssembly_elec" << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_elec.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_elec.H2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_elec.NOx << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_elec.CO << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_elec.SO2 << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_elec.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_elec.PM10 << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_elec.N2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_elec.PFC << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_elec.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_elec.HC << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_elec.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_elec.CO2 + theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_elec.CH4 * 25 << std::endl;
          csv << "FinalAssembly_heat" << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_heat.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_heat.H2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_heat.NOx << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_heat.CO << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_heat.SO2 << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_heat.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_heat.PM10 << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_heat.N2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_heat.PFC << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_heat.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_heat.HC << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_heat.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_heat.CO2 + theLifeCycleEmissionsSchaefer.theProduction.finalAssembly_heat.CH4 * 25 << std::endl;
          csv << "Transport (incl. Fuel Prod.)" << del << theLifeCycleEmissionsSchaefer.theProduction.transport.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.transport.H2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.transport.NOx << del <<
               theLifeCycleEmissionsSchaefer.theProduction.transport.CO << del <<
               theLifeCycleEmissionsSchaefer.theProduction.transport.SO2 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.transport.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.transport.PM10 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.transport.N2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.transport.PFC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.transport.NMVOC << del << theLifeCycleEmissionsSchaefer.theProduction.transport.HC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.transport.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theProduction.transport.CO2 + theLifeCycleEmissionsSchaefer.theProduction.transport.CH4 * 25 << std::endl;
          csv << "FinalTestFlights (incl. Fuel Prod." << del << theLifeCycleEmissionsSchaefer.theProduction.finalFlightTests.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalFlightTests.H2O << del << theLifeCycleEmissionsSchaefer.theProduction.finalFlightTests.NOx << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalFlightTests.CO << del << theLifeCycleEmissionsSchaefer.theProduction.finalFlightTests.SO2 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalFlightTests.CH4 << del << theLifeCycleEmissionsSchaefer.theProduction.finalFlightTests.PM10 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalFlightTests.N2O << del << theLifeCycleEmissionsSchaefer.theProduction.finalFlightTests.PFC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalFlightTests.NMVOC << del << theLifeCycleEmissionsSchaefer.theProduction.finalFlightTests.HC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalFlightTests.CED << del << theLifeCycleEmissionsSchaefer.theProduction.testFlightFuel << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalFlightTests.CO2 + theLifeCycleEmissionsSchaefer.theProduction.finalFlightTests.CH4 * 25 << std::endl;
          /*csv << "FinalTestFlightFuelProd" << del << finalTestFuelProd.CO2 << del << finalTestFuelProd.H2O << del <<
               finalTestFuelProd.NOx << del << finalTestFuelProd.CO << del << finalTestFuelProd.SO2 << del <<
               finalTestFuelProd.CH4 << del << finalTestFuelProd.PM10 << del << finalTestFuelProd.N2O << del <<
               finalTestFuelProd.PFC << del << finalTestFuelProd.NMVOC << del <<
               finalTestFuelProd.HC << del << 0. << del << 0. << std::endl;*/
          csv << std::endl << std::endl;
          csv << "# Operation Phase " << std::endl;
          csv << "# (1)EmissionName; (2)CO2; (3)H2O; (4)NOx; (5)CO; (6)SO2; (7)CH4; (8)PM10; (9)N2O; (10)PFC; (11)NMVOC;"
                    " (12)HC; (13) Energy; (14) AC Fuel; (15) GWP100" << std::endl;
          csv << "Operation_total" << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operation_total.CO2 << del << theLifeCycleEmissionsSchaefer.theOperation.operation_total.H2O << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operation_total.NOx << del << theLifeCycleEmissionsSchaefer.theOperation.operation_total.CO << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operation_total.SO2 << del << theLifeCycleEmissionsSchaefer.theOperation.operation_total.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operation_total.PM10 << del << theLifeCycleEmissionsSchaefer.theOperation.operation_total.N2O << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operation_total.PFC << del << theLifeCycleEmissionsSchaefer.theOperation.operation_total.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operation_total.HC << del << theLifeCycleEmissionsSchaefer.theOperation.operation_total.CED << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationFuel << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operation_total.CO2 + theLifeCycleEmissionsSchaefer.theOperation.operation_total.CH4 * 25 << std::endl;
          csv << "Operation Fuel Missions" << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationMissions.CO2 << del << theLifeCycleEmissionsSchaefer.theOperation.operationMissions.H2O << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationMissions.NOx << del << theLifeCycleEmissionsSchaefer.theOperation.operationMissions.CO << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationMissions.SO2 << del << theLifeCycleEmissionsSchaefer.theOperation.operationMissions.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationMissions.PM10 << del << theLifeCycleEmissionsSchaefer.theOperation.operationMissions.N2O << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationMissions.PFC << del << theLifeCycleEmissionsSchaefer.theOperation.operationMissions.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationMissions.HC << del << 0. << del << theLifeCycleEmissionsSchaefer.theOperation.operationFuel << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationMissions.CO2 + theLifeCycleEmissionsSchaefer.theOperation.operationMissions.CH4 * 25 << std::endl;
          csv << "FuelProd Missions" << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationFuelProduction.CO2 << del << theLifeCycleEmissionsSchaefer.theOperation.operationFuelProduction.H2O << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationFuelProduction.NOx << del << theLifeCycleEmissionsSchaefer.theOperation.operationFuelProduction.CO << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationFuelProduction.SO2 << del << theLifeCycleEmissionsSchaefer.theOperation.operationFuelProduction.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationFuelProduction.PM10 << del << theLifeCycleEmissionsSchaefer.theOperation.operationFuelProduction.N2O << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationFuelProduction.PFC << del << theLifeCycleEmissionsSchaefer.theOperation.operationFuelProduction.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationFuelProduction.HC << del << theLifeCycleEmissionsSchaefer.theOperation.operationFuelProduction.CED << del <<
               0. << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationFuelProduction.CO2 + theLifeCycleEmissionsSchaefer.theOperation.operationFuelProduction.CH4 * 25 << std::endl;
          csv << "MaintenanceLabour" << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintLabour_total.CO2 << del << theLifeCycleEmissionsSchaefer.theOperation.maintLabour_total.H2O << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintLabour_total.NOx << del << theLifeCycleEmissionsSchaefer.theOperation.maintLabour_total.CO << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintLabour_total.SO2 << del << theLifeCycleEmissionsSchaefer.theOperation.maintLabour_total.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintLabour_total.PM10 << del << theLifeCycleEmissionsSchaefer.theOperation.maintLabour_total.N2O << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintLabour_total.PFC << del << theLifeCycleEmissionsSchaefer.theOperation.maintLabour_total.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintLabour_total.HC << del << theLifeCycleEmissionsSchaefer.theOperation.maintLabour_total.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintLabour_total.CO2 + theLifeCycleEmissionsSchaefer.theOperation.maintLabour_total.CH4 * 25 << std::endl;
          csv << "MaintenanceLabour_elec" << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintLabour_elec.CO2 << del << theLifeCycleEmissionsSchaefer.theOperation.maintLabour_elec.H2O << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintLabour_elec.NOx << del << theLifeCycleEmissionsSchaefer.theOperation.maintLabour_elec.CO << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintLabour_elec.SO2 << del << theLifeCycleEmissionsSchaefer.theOperation.maintLabour_elec.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintLabour_elec.PM10 << del << theLifeCycleEmissionsSchaefer.theOperation.maintLabour_elec.N2O << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintLabour_elec.PFC << del << theLifeCycleEmissionsSchaefer.theOperation.maintLabour_elec.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintLabour_elec.HC << del << theLifeCycleEmissionsSchaefer.theOperation.maintLabour_elec.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintLabour_elec.CO2 + theLifeCycleEmissionsSchaefer.theOperation.maintLabour_elec.CH4 * 25 << std::endl;
          csv << "MaintenanceLabour_heat" << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintLabour_heat.CO2 << del << theLifeCycleEmissionsSchaefer.theOperation.maintLabour_heat.H2O << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintLabour_heat.NOx << del << theLifeCycleEmissionsSchaefer.theOperation.maintLabour_heat.CO << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintLabour_heat.SO2 << del << theLifeCycleEmissionsSchaefer.theOperation.maintLabour_heat.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintLabour_heat.PM10 << del << theLifeCycleEmissionsSchaefer.theOperation.maintLabour_heat.N2O << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintLabour_heat.PFC << del << theLifeCycleEmissionsSchaefer.theOperation.maintLabour_heat.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintLabour_heat.HC << del << theLifeCycleEmissionsSchaefer.theOperation.maintLabour_heat.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintLabour_heat.CO2 + theLifeCycleEmissionsSchaefer.theOperation.maintLabour_heat.CH4 * 25 << std::endl;
          csv << "SpareParts_total" << del <<
               theLifeCycleEmissionsSchaefer.theOperation.spareParts_total.CO2 << del << theLifeCycleEmissionsSchaefer.theOperation.spareParts_total.H2O << del <<
               theLifeCycleEmissionsSchaefer.theOperation.spareParts_total.NOx << del << theLifeCycleEmissionsSchaefer.theOperation.spareParts_total.CO << del <<
               theLifeCycleEmissionsSchaefer.theOperation.spareParts_total.SO2 << del << theLifeCycleEmissionsSchaefer.theOperation.spareParts_total.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theOperation.spareParts_total.PM10 << del << theLifeCycleEmissionsSchaefer.theOperation.spareParts_total.N2O << del <<
               theLifeCycleEmissionsSchaefer.theOperation.spareParts_total.PFC << del << theLifeCycleEmissionsSchaefer.theOperation.spareParts_total.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theOperation.spareParts_total.HC << del << theLifeCycleEmissionsSchaefer.theOperation.spareParts_total.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theOperation.spareParts_total.CO2 + theLifeCycleEmissionsSchaefer.theOperation.spareParts_total.CH4 * 25 << std::endl;
          csv << std::endl << std::endl;
          csv << "# End-of-Life Phase " << std::endl;
          csv << "# (1)EmissionName; (2)CO2; (3)H2O; (4)NOx; (5)CO; (6)SO2; (7)CH4; (8)PM10; (9)N2O; (10)PFC; (11)NMVOC;"
                    " (12)HC; (13) Energy; (14) AC Fuel; (15) GWP100" << std::endl;
          csv << "EndOfLife_total" << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.CO2 << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.H2O << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.NOx << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.CO << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.SO2 << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.PM10 << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.N2O << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.PFC << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.HC << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.CED << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.transportFuel << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.CO2 + theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLife_total.CH4 * 25 << std::endl;
          csv << "Transport (incl. Fuel Prod.)" << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.eoLTransport.CO2 << del << theLifeCycleEmissionsSchaefer.theEndOfLife.eoLTransport.H2O << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.eoLTransport.NOx << del << theLifeCycleEmissionsSchaefer.theEndOfLife.eoLTransport.CO << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.eoLTransport.SO2 << del << theLifeCycleEmissionsSchaefer.theEndOfLife.eoLTransport.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.eoLTransport.PM10 << del << theLifeCycleEmissionsSchaefer.theEndOfLife.eoLTransport.N2O << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.eoLTransport.PFC << del << theLifeCycleEmissionsSchaefer.theEndOfLife.eoLTransport.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.eoLTransport.HC << del << theLifeCycleEmissionsSchaefer.theEndOfLife.eoLTransport.CED << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.transportFuel << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.eoLTransport.CO2 + theLifeCycleEmissionsSchaefer.theEndOfLife.eoLTransport.CH4 * 25 << std::endl;
          /*csv << "Transport Fuel Production" << del << theLifeCycleEmissionsSchaefer.theEndOfLife.eoLTransportFuelProduction.CO2 << del << theLifeCycleEmissionsSchaefer.theEndOfLife.eoLTransportFuelProduction.H2O << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.eoLTransportFuelProduction.NOx << del << theLifeCycleEmissionsSchaefer.theEndOfLife.eoLTransportFuelProduction.CO << del << theLifeCycleEmissionsSchaefer.theEndOfLife.eoLTransportFuelProduction.SO2 << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.eoLTransportFuelProduction.CH4 << del << theLifeCycleEmissionsSchaefer.theEndOfLife.eoLTransportFuelProduction.PM10 << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.eoLTransportFuelProduction.N2O << del << theLifeCycleEmissionsSchaefer.theEndOfLife.eoLTransportFuelProduction.PFC << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.eoLTransportFuelProduction.NMVOC << del << theLifeCycleEmissionsSchaefer.theEndOfLife.eoLTransportFuelProduction.HC << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.eoLTransportFuelProduction.CED << del << 0. << std::endl;*/
          csv << "Disass. and Dismantling" << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.eoLDisassDism.CO2 << del << theLifeCycleEmissionsSchaefer.theEndOfLife.eoLDisassDism.H2O << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.eoLDisassDism.NOx << del << theLifeCycleEmissionsSchaefer.theEndOfLife.eoLDisassDism.CO << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.eoLDisassDism.SO2 << del << theLifeCycleEmissionsSchaefer.theEndOfLife.eoLDisassDism.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.eoLDisassDism.PM10 << del << theLifeCycleEmissionsSchaefer.theEndOfLife.eoLDisassDism.N2O << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.eoLDisassDism.PFC << del << theLifeCycleEmissionsSchaefer.theEndOfLife.eoLDisassDism.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.eoLDisassDism.HC << del << theLifeCycleEmissionsSchaefer.theEndOfLife.eoLDisassDism.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.eoLDisassDism.CO2 + theLifeCycleEmissionsSchaefer.theEndOfLife.eoLDisassDism.CH4 * 25 << std::endl;
          csv << "EoL Scen. Total" << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.materialEoL_total.CO2 << del << theLifeCycleEmissionsSchaefer.theEndOfLife.materialEoL_total.H2O << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.materialEoL_total.NOx << del << theLifeCycleEmissionsSchaefer.theEndOfLife.materialEoL_total.CO << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.materialEoL_total.SO2 << del << theLifeCycleEmissionsSchaefer.theEndOfLife.materialEoL_total.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.materialEoL_total.PM10 << del << theLifeCycleEmissionsSchaefer.theEndOfLife.materialEoL_total.N2O << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.materialEoL_total.PFC << del << theLifeCycleEmissionsSchaefer.theEndOfLife.materialEoL_total.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.materialEoL_total.HC << del << theLifeCycleEmissionsSchaefer.theEndOfLife.materialEoL_total.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.materialEoL_total.CO2 + theLifeCycleEmissionsSchaefer.theEndOfLife.materialEoL_total.CH4 * 25 << std::endl;
          csv << std::endl << std::endl;
          csv.close();
     }
}


