/**
 * \file dallaraConfig.cpp
 * \author Katrin Bistreck (katrin.bistreck@tuhh.de)
 * \brief configuration class for reading schaefer data from conf.xml
 * \version 0.1
 * \date 2023-12-04
 *
 * @copyright Copyright (c) 2023
 *
 */

#include "dallaraConfig.h"

#include <aixml/node.h>

DallaraConfig::DallaraConfig()
    :
    s_i_heightVariation_AIC(0.),
    s_i_heightVariation_O3S(0.),
    s_i_heightVariation_CH4O3L(0.),
    fuelAICfactor(0.),
    s_i_dataSet(""),
    tmax(0),
    devRate(0.) {
    }

void DallaraConfig::readAllConfigData(const node& configXML) {
    fuelAICfactor = EndnodeReadOnly<double>(std::string("program_settings/standard_strategy/impact_calculation/")
                    + std::string("climate_model_methods/dallara/fuel_factor_AIC")).read(configXML).value();
    tmax = EndnodeReadOnly<int>(std::string("program_settings/standard_strategy/impact_calculation/")
            + std::string("climate_model_methods/dallara/max_integration_period")).read(configXML).value_xml();
    devRate = EndnodeReadOnly<double>(std::string("program_settings/standard_strategy/impact_calculation/")
                + std::string("climate_model_methods/dallara/devaluation_rate")).read(configXML).value();
    readForcingFactorConfigData(configXML.at("program_settings/standard_strategy/impact_calculation/climate_model_methods/dallara/forcing_factors"));
}

void DallaraConfig::readForcingFactorConfigData(const node& forcingFactor) {
    s_i_heightVariation_AIC = EndnodeReadOnly<double>("/variations/aircraft_induced_cloudiness").read(forcingFactor).value();
    s_i_heightVariation_O3S = EndnodeReadOnly<double>("/variations/short_lived_ozone").read(forcingFactor).value();
    s_i_heightVariation_CH4O3L = EndnodeReadOnly<double>("/variations/methan_and_long_lived_ozone").read(forcingFactor).value();
    s_i_dataSet = EndnodeReadOnly<std::string>("/data_set_selector").read(forcingFactor).value();
}

DallaraConfig::~DallaraConfig() {
    //dtor
}

