/*  Copyright (C) 2012-2022 Institute of Aerospace Systems, RWTH Aachen University - All rights reserved.
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef performance_assessment_SRC_TAW_DEFAULTMETHODS_ENGINEPERFORMANCE_ABSTRACTENGINEPERFORMANCE_H_
#define performance_assessment_SRC_TAW_DEFAULTMETHODS_ENGINEPERFORMANCE_ABSTRACTENGINEPERFORMANCE_H_

#include <vector>
#include <string>

class abstractEnginePerformance
{
 public:
    virtual ~abstractEnginePerformance() { }

    /**\class enginePerfParameter Class that contains the engine performance parameters
    *
    */
    class enginePerfParameter {
     public:
        double Altitude; /**< Aircraft altitude (m) */
        vector<double> Mach; /**< List of aircraft Mach number from 0 to maximum operating Mach number (-) */
        vector<double> Thrust; /**< List of thrust per engine for different altitudes, flight speeds and engine ratings (kN) */
        vector<double> SFC; /**< List of specific fuel consumptions for different altitudes, flight speeds and engine ratings (mg/Ns) */

        /** \brief Constructor enginePerfParameter
        *
        */
        enginePerfParameter() {
            Altitude = 0.0;
        }
    };

    /** \class dataEnginePerformance Class that contains engine performance for different altitudes
    *
    */
    class dataEnginePerformance {
     public:
        string Rating; /**< Engine rating */
        vector<enginePerfParameter> theParameter; /**< List of the engine performance parameter */

        /**\brief Constructor of the dataEnginePerformance object
        *
        */
        dataEnginePerformance()
            :
            Rating("") {
        }
    };
    vector<dataEnginePerformance> theRatingEngine; /**< List of the engine performance data */

    /** \brief Calculates the aircraft engine performance for different engine ratings
    * \param engineRating vector with engine rating
    */
    virtual void doEngineCalculation(std::vector<std::string> engineRating) = 0;
};




#endif  // performance_assessment_SRC_TAW_DEFAULTMETHODS_ENGINEPERFORMANCE_ABSTRACTENGINEPERFORMANCE_H_
