/*  Copyright (C) 2012-2022 Institute of Aerospace Systems, RWTH Aachen University - All rights reserved.
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/
#include "enginePerformance.h"

using std::vector;
using std::string;

namespace low {

enginePerformance::enginePerformance(std::shared_ptr<aircraft> theAircraftPt)
    :
    maxThrust(0.0) {
    // ctor
}
enginePerformance::~enginePerformance() {
    // dtor
}

void enginePerformance::doEngineCalculation(vector<string> theRating) {
    for (unsigned int i(0); i <= theRating.size() - 1; i++) {
        theRatingEngine.push_back(dataEnginePerformance());
        theRatingEngine.back().Rating = theRating.at(i);
        for (double alt = 0.; alt <= 0.3048 * 45000.; alt += 0.3048 * 5000.) {
            theRatingEngine.back().theParameter.push_back(enginePerfParameter());
            theRatingEngine.back().theParameter.back().Altitude = alt;
            for (double mach = 0.0; mach <= theAircraftPt->MMO; mach += 0.05) {
                theAircraftPt->myEngines.calculate_N1_with_penalties(theAircraftPt->myEnergyProviders.energyCarrierID_cruise, alt, mach, theAircraftPt->atm, 1.,
                    theRatingEngine.back().Rating, 0., 0.);
                theRatingEngine.back().theParameter.back().Mach.push_back(mach);
                theRatingEngine.back().theParameter.back().Thrust.push_back(theAircraftPt->myEngines.get_thrust_aircraft(theAircraftPt->myEnergyProviders.energyCarrierID_cruise)
                    / 2);
                theRatingEngine.back().theParameter.back().SFC.push_back(theAircraftPt->myEngines.get_thrust_aircraft(theAircraftPt->myEnergyProviders.energyCarrierID_cruise)
                    / theAircraftPt->myEngines.get_thrust_aircraft(theAircraftPt->myEnergyProviders.energyCarrierID_cruise));
            }
        }
    }
    maxThrust = getMaxThrust();
}

double enginePerformance::getMaxThrust() {
    double tempThrust(0.0);
    for (unsigned int i(0); i <= theRatingEngine.size() - 1; i++) {
        if (tempThrust <= theRatingEngine.at(i).theParameter.at(0).Thrust.at(0)) {
            tempThrust = theRatingEngine.at(i).theParameter.at(0).Thrust.at(0);
        }
    }
    return tempThrust;
}

}  // namespace low
