/*  Copyright (C) 2023 Chair of Aircraft Design, Technical University Munich
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/
/**
 * @file nacelle_design.h
 * @author Sebastian Oberschwendtner (sebastian.oberschwendtner@tum.de)
 * @brief The base design class for nacelle geometry design.
 * @version 3.0.0
 * @date 2023-12-20
 */

#ifndef SRC_NACELLE_NACELLE_DESIGN_H_
#define SRC_NACELLE_NACELLE_DESIGN_H_

/* === Includes === */
#include "../propulsion.h"
#include "../propulsion_strategy.h"
#include <filesystem>
#include <memory>

namespace geometry
{
    /* === Classes === */
    /**
     * @class NacelleDesigner
     * @brief The base design class for nacelle geometry design.
     *
     */
    class NacelleDesigner : public PropulsionStrategy
    {
      public:
        /* === Constructors === */
        /**
         * @brief Construct a new Nacelle Designer object
         * @param configuration The module configuration provided by the user.
         * @param geometry_directory The directory where the geometry files are stored.
         */
        NacelleDesigner(const std::shared_ptr<node> &configuration, const std::filesystem::path &geometry_directory)
            : PropulsionStrategy(configuration), geometry_directory_(geometry_directory) {}

        /* === Methods === */
        [[nodiscard]] auto geometry_directory() const -> const std::filesystem::path { return this->geometry_directory_; }

      private:
        const std::filesystem::path geometry_directory_; /**< The directory where the geometry files are stored. */
    };
}; // namespace geometry

#endif // SRC_NACELLE_NACELLE_DESIGN_H_
