/**
 * \file controlDeviceMethods.h
 * \author Christopher Ruwisch (christopher.ruwisch@tu-berlin.de)
 * \brief Control device methods
 * \version 0.1
 * \date 2024-01-11
 *
 * @copyright Copyright (c) 2024
 *
 */
#ifndef CONTROL_DEVICE_METHODS
#define CONTROL_DEVICE_METHODS

#include <aircraftGeometry2/geometry/surface.h>

#include <iostream>
#include <tuple>

#include "lib/io_methods/controlDeviceIO.h"
using modes = std::string;

namespace user_defined {
std::tuple<std::vector<geom2::MultisectionSurface<geom2::PolygonSection>>, std::vector<std::tuple<double, double>>>
control_devices(std::vector<ControlDevice> devices);
}  // namespace user_defined

namespace empirical {
std::tuple<std::vector<geom2::MultisectionSurface<geom2::PolygonSection>>, std::vector<std::tuple<double, double>>>
control_devices(const std::vector<geom2::MultisectionSurface<geom2::PolygonSection>>& spars,
                const geom2::MultisectionSurface<geom2::AirfoilSection>& wing,
                const geom2::MultisectionSurface<geom2::PolygonSection>& fuselage, const bool is_kinked,
                const double eta_kink, const std::string& config_leading_edge_high_lift_device_type,
                const std::string& config_trailing_edge_high_lift_device_type);
}  // namespace empirical

std::tuple<std::vector<geom2::MultisectionSurface<geom2::PolygonSection>>, std::vector<std::tuple<double, double>>>
get_control_devices(modes control_device_mode, std::vector<ControlDevice> devices,
                    const std::vector<geom2::MultisectionSurface<geom2::PolygonSection>>& spars,
                    const geom2::MultisectionSurface<geom2::AirfoilSection>& wing,
                    const geom2::MultisectionSurface<geom2::PolygonSection>& fuselage, const bool is_kinked,
                    const double eta_kink, const std::string& config_leading_edge_high_lift_device_type,
                    const std::string& config_trailing_edge_high_lift_device_type);

#endif  // CONTROL_DEVICE_METHODS