/**
 * @file newtonAlgorithm.h
 * @author Christopher Ruwisch (christopher.ruwisch@...)
 * @brief Newton algorithm
 * @version 0.1
 * @date 2023-11-03
 *
 * @copyright Copyright (c) 2023
 *
 */
#ifndef NEWTON_ALGORITHM_H_
#define NEWTON_ALGORITHM_H_

#include <functional>
#include <iostream>
#include <limits>

double newton_algorithm(auto& fun, double x0) {
  double fx, fxh, fx_;
  double x = x0;
  constexpr double h = 0.001;
  do {
    fx = fun(x);
    fxh = fun(x + h);
    fx_ = (fxh - fx) / h;
    x -= fx / fx_;
  } while (abs(fx) > 1e-10 && abs(fx - fxh) > 1e-13);

  return x;
}

double newton_algorithm(auto& fun, auto& fun_, double x0) {
  double fx, fx_, x = x0;
  do {
    fx = fun(x);
    fx_ = fun_(x);
    x -= fx / fx_;
  } while (abs(fx) > 1e-10);

  return x;
}

#endif  // NEWTON_ALGORITHM_H_