/**
 * \file controlDeviceIO.h
 * \author Christopher Ruwisch (christopher.ruwisch@tu-berlin.de)
 * \brief Control Device IO
 * \version 0.1
 * \date 2024-01-11
 *
 * @copyright Copyright (c) 2024
 *
 */
#ifndef CONTROL_DEVICE_IO_H_
#define CONTROL_DEVICE_IO_H_

#include "relativePositionIO.h"

class ControlDevice {
 public:
  ControlDevice() = default;
  ControlDevice(const std::string& origin)
      : type(EndnodeReadOnly<std::string>(origin + "type")),
        deflection_full_negative(EndnodeReadOnly<double>(origin + "deflection/full_negative_deflection")),
        deflection_full_positive(EndnodeReadOnly<double>(origin + "deflection/full_positive_deflection")),
        position(RelativePosition(origin)) {}
  EndnodeReadOnly<std::string> type;
  EndnodeReadOnly<double> deflection_full_negative;
  EndnodeReadOnly<double> deflection_full_positive;
  RelativePosition position;

  void read(const node& xml) {
    type.read(xml);
    deflection_full_negative.read(xml);
    deflection_full_positive.read(xml);
    position.read(xml);
  }
};

#endif  // CONTROL_DEVICE_IO_H_